# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# Operation failed.
FAILEDOPERATION = 'FailedOperation'

# Operation not allowed as your account is in arrears.
FAILEDOPERATION_USERFEENEGATIVE = 'FailedOperation.UserFeeNegative'

# Internal error.
INTERNALERROR = 'InternalError'

# Incorrect parameter.
INVALIDPARAMETER = 'InvalidParameter'

# Invalid date.
INVALIDPARAMETER_DATEINVALID = 'InvalidParameter.DateInvalid'

# The entered query date range is longer than 60 days.
INVALIDPARAMETER_DATEOUTOFSIXTYDAYS = 'InvalidParameter.DateOutOfSixtyDays'

# Incorrect tag.
INVALIDPARAMETER_TAGKEY = 'InvalidParameter.TagKey'

# Incorrect query time range.
INVALIDPARAMETER_TIMERANGEERROR = 'InvalidParameter.TimeRangeError'

# Invalid BizId.
INVALIDPARAMETERVALUE_INVALIDBIZID = 'InvalidParameterValue.InvalidBizId'

# Invalid RecordMode.
INVALIDPARAMETERVALUE_INVALIDRECORDMODE = 'InvalidParameterValue.InvalidRecordMode'

# Invalid RoomId.
INVALIDPARAMETERVALUE_INVALIDROOMID = 'InvalidParameterValue.InvalidRoomId'

# Incorrect blocklist/allowlist format.
INVALIDPARAMETERVALUE_INVALIDSUBSCRIBERECORDUSERIDS = 'InvalidParameterValue.InvalidSubscribeRecordUserIds'

# The number of entries on the allowlist exceeds 20.
INVALIDPARAMETERVALUE_INVALIDSUBSCRIBEUSERIDS = 'InvalidParameterValue.InvalidSubscribeUserIds'

# Invalid taskid.
INVALIDPARAMETERVALUE_INVALIDTASKID = 'InvalidParameterValue.InvalidTaskId'

# The number of entries on the blocklist exceeds 20.
INVALIDPARAMETERVALUE_INVALIDUNSUBSCRIBEUSERIDS = 'InvalidParameterValue.InvalidUNSubscribeUserIds'

# The number of created applications has reached the upper limit.
LIMITEXCEEDED_APPLICATION = 'LimitExceeded.Application'

# Parameter missing.
MISSINGPARAMETER = 'MissingParameter'

# The task already exists.
RESOURCEINUSE_TASKINUSE = 'ResourceInUse.TaskInUse'

# The resource does not exist.
RESOURCENOTFOUND = 'ResourceNotFound'

# Incorrect application ID.
RESOURCENOTFOUND_BIZIDISNOTFOUND = 'ResourceNotFound.BizidIsNotFound'

# The room does not exist.
RESOURCENOTFOUND_ROOMNOTFOUND = 'ResourceNotFound.RoomNotFound'

# The task ID does not exist.
RESOURCENOTFOUND_TASKNOTFOUND = 'ResourceNotFound.TaskNotFound'

# Unauthorized operation.
UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'

# Application creation is not authorized.
UNAUTHORIZEDOPERATION_CREATEAPPDENIED = 'UnauthorizedOperation.CreateAppDenied'

# Unverified user.
UNAUTHORIZEDOPERATION_UNREALNAMEAUTH = 'UnauthorizedOperation.UnRealNameAuth'

# Unknown parameter error.
UNKNOWNPARAMETER = 'UnknownParameter'

# Operation unsupported.
UNSUPPORTEDOPERATION = 'UnsupportedOperation'

# The recording service is not activated.
UNSUPPORTEDOPERATION_SERVICENOTOPENED = 'UnsupportedOperation.ServiceNotOpened'
